@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #include <stdio.h>
@@ -146,8 +146,8 @@ int getRetrySecs()
     char* value = dupVarValue("RetrySeconds");
     if (value != NULL) {
         int v = atoi(value);
-	free(value);
-	return v;
+        free(value);
+        return v;
     }
     return 10;
 }
@@ -163,9 +163,9 @@ void setWaitTime(const char* value)
     
     if (value != NULL) {
         waitTimeout = atoi(value);
-	if (waitTimeout < 0) {
-	    waitTimeout = -1; 
-	}
+	    if (waitTimeout < 0) {
+	        waitTimeout = -1; 
+	    }
     }
 }
 
@@ -275,16 +275,6 @@ int getFrontEnd()
     return conf.frontEnd;
 }
 
-char* getCfgDir(void)
-{
-    return dupVarValue("CfgDir");
-}
-
-char* getConfigDir(void)
-{
-    return conf.cfgDir;
-}
-
 void setModel (char *answer)
 {
     if (answer == NULL) {
@@ -359,7 +349,7 @@ static type_key* findStartingWith(mode *mode, const char *key)
     while (It && It->key != NULL) {
         char *start = strstr(It->key,key);
 	
-	     //DEBUG2("findStartingWith() %s %s %s",It->key,key,(start?"FOUND":"NOTFOUND"));
+	     //DEBUG2("[EX]: findStartingWith() %s %s %s",It->key,key,(start?"FOUND":"NOTFOUND"));
 
         if (start && start == It->key) {    // We got a part of multi-key or parametrized command
 
@@ -377,7 +367,7 @@ static type_key* findStartingWith(mode *mode, const char *key)
 	    }
 	    
 	    if (ok == 1)  {
-        	logger(L_DBG,"Found part of multi-key or parametrized command");
+        	logger(L_DBG,"[EX]: Found part of multi-key or parametrized command");
         	return It;
 	    }
         }
@@ -524,7 +514,7 @@ static type_key* findItemInMode(mode *mode, const char *key, int *flag, cmdParam
 
         if (It) {
             if(canLog) {
-                logger(L_DBG,"[EX]: Found exact (explicitly specified by value) parametrized command");
+                logger(L_DBG,"[EX]: Found exact (specified by value) parametrized command");
             }
             *flag = FLAG_EXACT;
 	    
@@ -551,27 +541,27 @@ static type_key* findItemInMode(mode *mode, const char *key, int *flag, cmdParam
         free(keyAndBrace);
         if (It) {
             if(canLog) {
-                DEBUG2("Found parametrized command >%s,%s< ", index,decodedVal);
+                DEBUG2("EX]: Found parametrized command >%s,%s< ", index,decodedVal);
             }
             strcpy(params->index, index);
             strcpy(params->value, decodedVal);
 
             *flag = FLAG_PARAMETR;
+
+	        #ifdef USE_ICONV
+	        if (needFree) {
+	            free(decodedVal);
+	        }
+	        #endif
 	    
+            return It;
+        }
+	
 	    #ifdef USE_ICONV
 	    if (needFree) {
 	        free(decodedVal);
 	    }
 	    #endif
-	    
-            return It;
-        }
-	
-	#ifdef USE_ICONV
-	if (needFree) {
-	    free(decodedVal);
-	}
-	#endif
     }
     //if(canLog) {
     //    logger(L_DBG,"[EX]: findItemInMode: not found");
@@ -590,7 +580,7 @@ type_key* findItemInModeAndParents(mode* curMode, const char *key, int *flag, cm
     	
 	
     	    string_t* parent = stringNew(curMode->parent->str);
-    	    char* ptrptr;
+    	    char* ptrptr = NULL;
     	    char* pmode  = strtok_r(parent->str,",", &ptrptr); 
     	    
     	    while (pmode) {
@@ -814,8 +804,5 @@ void freeCmds(SingleList* commands)
 void freeCfg(void)
 {
     logger(L_DBG, "freeCfg()");
-    
     freeModes(NULL); // delete all modes stuff
-
-    free(conf.cfgDir);
 }
