@@ -237,11 +237,14 @@ static int handleStringMsg(int peer, void * ptr)
     return 0;
 }
 
-static int handleEventMsg(int peer, void * ptr)
+static int handleEventMsg(int peer, void* ptr)
 {
-    int* evt = (int*) ptr;
-
     int exitFlag = 0;
+    if (ptr == NULL) {
+        return exitFlag;
+    }
+    
+    int* evt = (int*) ptr;
 
     if (*evt == ID_EVT_CONNECT) {
         logger(L_DBG, "[EX]: got event EVT_CONNECT");
@@ -834,7 +837,7 @@ static int isBemusedCommand(char *cmdIn)
                 strcat(oneCmd,")");
             }
 
-            DEBUG2("[EX]: isBemusedCommand: one commmand >%s<", oneCmd);
+            DEBUG2("[EX]: isBemusedCommand: one command >%s<", oneCmd);
 
             handle_key_press(PEER_ANY,oneCmd,1);
         } else {
@@ -933,7 +936,7 @@ static int isInpLircCommand(char *cmdIn)
     }
 
     if (isLirc) {
-        DEBUG2("[EX]: isLircCommand: one commmand >%s<", data);
+        DEBUG2("[EX]: isLircCommand: one command >%s<", data);
         handle_key_press(PEER_ANY,data,1);
     }
 
@@ -1009,7 +1012,7 @@ static int isIViewerCommand(char *cmdIn)
     }
     free(cmdTmp);
 
-    DEBUG2("[EX]: isIViewerCommand: one commmand >%s<", cmd);
+    DEBUG2("[EX]: isIViewerCommand: one command >%s<", cmd);
     handle_key_press(PEER_ANY,cmd,1);
 
     logger(L_INF, "[EX]: isIViewerCommand: EXIT");
