@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2011-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #include <ctype.h>
@@ -31,6 +31,7 @@
 #include "state.h"
 #include "gen_xml.h"
 #include "mutex.h"
+#include "var.h"
 
 // not to include pr_web.h
 extern void addLink(string_t* ip, string_t* addTo, int port, boolean_t trailSlash);
@@ -39,23 +40,25 @@ extern void addLink(string_t* ip, string_t* addTo, int port, boolean_t trailSlas
 
 #define XML_HEAD1  "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
 
-//#define XML_CFORM1  "<CiscoIPPhoneMenu>\n"
-//#define XML_CFORM99 "</CiscoIPPhoneMenu>\n"
-#define XML_CFORM1  "<CiscoIPPhoneGraphicFileMenu>\n"
-#define XML_CFORM99 "</CiscoIPPhoneGraphicFileMenu>\n"
+#define XML_CFORM1  "<CiscoIPPhoneMenu>\n"
+#define XML_CFORM99 "</CiscoIPPhoneMenu>\n"
+#define XML_CFORM1G  "<CiscoIPPhoneGraphicFileMenu>\n"
+#define XML_CFORM99G "</CiscoIPPhoneGraphicFileMenu>\n"
 
 /*
 x-CiscoIPPhoneModelName: CP-7941G
 x-CiscoIPPhoneSDKVersion: 7.0.1
 x-CiscoIPPhoneDisplay: 298,144,3,G
 
+Cisco Unified IP Phone  7905      192 x 53
+
 Cisco Unified IP Phone  7920      128 x 59 Grayscale 1
 Cisco Unified IP Phones 7940G
                         7960G     133 x 65 Grayscale 2
 Cisco Unified IP Phones 7941G,
                         7941G-GE,
                         7961G,
-			7961G-GE  298 x 144 Grayscale 4
+			            7961G-GE  298 x 144 Grayscale 4
 
 Cisco Unified IP Phone  7970G
                         7971G     298 x 168 Color     12
@@ -83,6 +86,8 @@ static int       _xmlLayoutW = 298;    //
 static int       _xmlLayoutH = 144;    //
 static boolean_t _xmlScreenG  = BOOL_YES;
 static boolean_t _xmlLayoutOk = BOOL_NO;
+static boolean_t _xmlGraphic  = BOOL_YES;
+
 
 int xmlScreenWidth()
 {
@@ -127,7 +132,7 @@ void parseScreenDef(char* buffer)
     int sW      = atoi(w);
     int sH      = atoi(h);
 
-    //printf("parseScreenDef w=%d h=%d d=%s g=%s\n", sW, sH, d, g);
+    //printf("parseScreenDef w=%d h=%d g=%s\n", sW, sH, g);
 
     boolean_t sG = (g && g[0] == 'G');  // Grayscale
 
@@ -146,6 +151,30 @@ void parseScreenDef(char* buffer)
     free(scrDef);
 }
 
+void parseCiscoModel(char* buffer)
+{
+    // x-CiscoIPPhoneModelName: CP-7905
+    //DEBUG2("[WS]:parseCiscoModel line: %s", buffer);
+
+    int gap = strlen("x-CiscoIPPhoneModelName: ");
+    if (!buffer || strlen(buffer) < gap) {
+        return;
+    }
+    
+    // http://www.cisco.com/c/en/us/td/docs/voice_ip_comm/cuipph/all_models/xsi/8_5_1/xsi_dev_guide/xmlobjects.html
+    char* start = buffer+gap;
+    if (strstr(start,"7905") ||  
+        strstr(start,"7906") ||
+        strstr(start,"7911") ||
+        strstr(start,"7912") ||
+        strstr(start,"7931") ||
+        strstr(start,"7940") ||
+        strstr(start,"7960")) {
+    
+        _xmlGraphic = BOOL_NO;
+    }
+}
+
 static void renderConvertCmd(string_t* cmd)
 {
     stringAppend(cmd, " -resize ");
@@ -283,7 +312,11 @@ string_t* renderXMLFormHead(int form, const char* caption)
     string_t* head = stringNew(XML_HEAD1);
 
     if (form == CF) {
-        stringAppend(head,XML_CFORM1);
+        if (_xmlGraphic == BOOL_YES) {
+            stringAppend(head,XML_CFORM1G);
+        } else {
+            stringAppend(head,XML_CFORM1);
+        }
     } else if (form == LI) {
         stringAppend(head,XML_LIST1);
     } else if (form == TX) {
@@ -291,7 +324,12 @@ string_t* renderXMLFormHead(int form, const char* caption)
     } else if (form == EF) {
         stringAppend(head,XML_EFORM1);
     } else if (form == WM) {
-        stringAppend(head,XML_WMAN1);
+        if (_xmlGraphic == BOOL_YES) {
+            stringAppend(head,XML_WMAN1);
+        } else {
+            stringAppend(head,XML_CFORM1);
+        }
+        
     }
 
     stringAppend(head, "  <Title>");
@@ -369,6 +407,7 @@ string_t* sendXMLMenu(int form, string_t* ip, int p, int idx)
     }
 
     stringAppend(page, "  <SoftKeyItem>\n    <Name>Select</Name>\n    <URL>SoftKey:Select</URL>\n    <Position>1</Position>\n  </SoftKeyItem>\n");
+    stringAppend(page, "  <SoftKeyItem>\n    <Name>Back</Name>\n    <URL>SoftKey:Back</URL>\n    <Position>2</Position>\n  </SoftKeyItem>\n");
 
     stringAppend(page, XML_LIST99);
     
@@ -388,7 +427,7 @@ static void renderXMLLayout()
 
     // Use ImageMagic to create picture to show
 
-    char* confDir = getCfgDir();
+    char* confDir = dupVarValue(VAR_CFGDIR);
     string_t* iconpath = stringNew(confDir ? confDir : ".");
     free(confDir);
     
@@ -481,24 +520,23 @@ static void renderXMLLayout()
     size_t sz = 0;
     char* dummy = executeCommandPipe(cmd->str, &sz);
     if (dummy) {  // can be NULL
-
         free(dummy);
+    }
 
-        char* buf = executeCommandPipe("identify -format \"%w,%h\" $HOME/.anyRemote/layout_xml.png", &sz);
-        if (buf) {
+    char* buf = executeCommandPipe("identify -format \"%w,%h\" $HOME/.anyRemote/layout_xml.png", &sz);
+    if (buf) {
 
-            char* w = strtok(buf, ",");
-            char* h = strtok(NULL,",");
+        char* w = strtok(buf, ",");
+        char* h = strtok(NULL,",");
 
-            _xmlLayoutW = atoi(w);
-            _xmlLayoutH = atoi(h);
-            INFO2("[WS]: renderXMLLayout rendered image is (%d,%d)", _xmlLayoutW, _xmlLayoutH);
+        _xmlLayoutW = atoi(w);
+        _xmlLayoutH = atoi(h);
+        INFO2("[WS]: renderXMLLayout rendered image is (%d,%d)", _xmlLayoutW, _xmlLayoutH);
 
-            free(buf);
+        free(buf);
 
-        } else {
-            ERROR2("[WS]: renderXMLLayout can not get size layout image");
-        }
+    } else {
+        ERROR2("[WS]: renderXMLLayout can not get size layout image");
     }
 
     stringFree(cmd,      BOOL_YES);
@@ -540,7 +578,7 @@ string_t* renderCtrlXMLForm(string_t* ip, int port)
 {
     INFO2("[WS]: renderCtrlXMLForm");
 
-    if (!_xmlLayoutOk) {
+    if (_xmlGraphic == BOOL_YES && !_xmlLayoutOk) {
         renderXMLLayout();
     }
     
@@ -548,26 +586,28 @@ string_t* renderCtrlXMLForm(string_t* ip, int port)
     string_t* page = renderXMLFormHead(CF, cfCaption());
     mutexUnlock(M_STATE);
     
-    stringAppend(page, "  <LocationX>");
-    
     char num[16];
     sprintf(num,"%d", (_xmlScreenW - _xmlLayoutW)/2);
-    stringAppend(page, num);
     
-    stringAppend(page, "</LocationX>\n");
+    if (_xmlGraphic == BOOL_YES) {
+        
+        stringAppend(page, "  <LocationX>");
+        stringAppend(page, num);
+        stringAppend(page, "</LocationX>\n");
 
-    stringAppend(page, "  <LocationY>");
-    
-    sprintf(num,"%d", (bottomlineSkin() ? _xmlScreenH - _xmlLayoutH : (_xmlScreenH - _xmlLayoutH)/2));
-    stringAppend(page, num);
-    
-    stringAppend(page, "</LocationY>\n");
+        stringAppend(page, "  <LocationY>");
 
-    stringAppend(page, "  <URL>");
+        sprintf(num,"%d", (bottomlineSkin() ? _xmlScreenH - _xmlLayoutH : (_xmlScreenH - _xmlLayoutH)/2));
+        stringAppend(page, num);
 
-    addLink(ip, page, port, BOOL_YES);
+        stringAppend(page, "</LocationY>\n");
 
-    stringAppend(page, "xml_layout</URL>\n");
+        stringAppend(page, "  <URL>");
+
+        addLink(ip, page, port, BOOL_YES);
+
+        stringAppend(page, "xml_layout</URL>\n");
+    }
 
     int i = 0;
     
@@ -582,7 +622,12 @@ string_t* renderCtrlXMLForm(string_t* ip, int port)
         }
 
         stringAppend(page, "  <MenuItem>\n   <Name>");
-        stringAppend(page, icon);
+        if (_xmlGraphic == BOOL_YES) {
+            stringAppend(page, icon);
+        } else {
+            const char* hint = cfHint(i);
+            stringAppend(page, hint);
+        }
         stringAppend(page, "</Name>\n   <URL>");
 
         addLink(ip, page, port, BOOL_YES);
@@ -600,8 +645,11 @@ string_t* renderCtrlXMLForm(string_t* ip, int port)
 
     addXMLFormMenu(CF, ip, page, port);
 
-    stringAppend(page, XML_CFORM99);
-    
+    if (_xmlGraphic == BOOL_YES) {
+        stringAppend(page, XML_CFORM99G);
+    } else {
+        stringAppend(page, XML_CFORM99);
+    }
     //printf("renderCtrlXMLForm FULL \n%s\n",page->str);
     return page;
 }
@@ -622,7 +670,6 @@ string_t* renderTextXMLForm(string_t* ip, int port)
     addXMLFormMenu(TX, ip, page, port);
 
     stringAppend(page, XML_TEXT99);
-    
     return page;
 }
 
@@ -644,10 +691,17 @@ string_t* renderListXMLForm(string_t* ip, int port)
         while (list && idx <= XML_MAX_LIST_SIZE) {
 
             stringAppend(page, "  <MenuItem>\n   <Name>");
+            char* listItem = ((ListItem*) list->data)->string->str;
+            int i = 0;
+            for (;i<((ListItem*) list->data)->string->len;i++) {
+                if (*(listItem+i) == '\''|| *(listItem+i) == '&') {
+                    *(listItem+i) = '-';
+                }
+            }
             if (((ListItem*) list->data)->string->len > CMXML_MAX_STRING_SIZE) {
-                stringAppendLen(page, ((ListItem*) list->data)->string->str, CMXML_MAX_STRING_SIZE);
+                stringAppendLen(page, listItem, CMXML_MAX_STRING_SIZE);
             } else {
-                stringAppend(page, ((ListItem*) list->data)->string->str);
+                stringAppend(page, listItem);
             }
             stringAppend(page, "</Name>\n   <URL>");
 
@@ -724,7 +778,7 @@ string_t* renderListXMLForm(string_t* ip, int port)
     }
 
     stringAppend(page, XML_LIST99);
-    
+    //printf("renderListXMLForm FULL \n%s\n",page->str);
     return page;
 }
 
@@ -736,18 +790,20 @@ string_t* renderWmanXMLForm(string_t* ip, int port)
     string_t* page = renderXMLFormHead(WM, cfCaption());
     mutexUnlock(M_STATE);
     
-    stringAppend(page, "  <LocationX>0</LocationX>\n");
-    stringAppend(page, "  <LocationY>0</LocationY>\n");
-    stringAppend(page, "  <URL>");
+    if (_xmlGraphic == BOOL_YES) {
+        stringAppend(page, "  <LocationX>0</LocationX>\n");
+        stringAppend(page, "  <LocationY>0</LocationY>\n");
+        stringAppend(page, "  <URL>");
 
-    addLink(ip, page, port, BOOL_YES);
+        addLink(ip, page, port, BOOL_YES);
 
-    stringAppend(page, "xml_image</URL>\n");
+        stringAppend(page, "xml_image</URL>\n");
+    }
 
     addXMLFormMenu(WM, ip, page, port);
 
     stringAppend(page, XML_WMAN99);
-    
+    //printf("renderWmanXMLForm FULL \n%s\n",page->str);
     return page;
 }
 
@@ -775,7 +831,6 @@ static string_t* renderEditXML(const char* caption, const char* label, const cha
     stringAppend(page, "  <SoftKeyItem>\n    <Name>&lt;&lt;</Name>\n    <URL>SoftKey:&lt;&lt;</URL>\n    <Position>3</Position>\n  </SoftKeyItem>\n");
 
     stringAppend(page, XML_EFORM99);
-    
     return page;
 }
 
