@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #ifndef _PARSE_H_
@@ -63,7 +63,8 @@
 #define DEF_CLCC 	"+CLCC:"
 #define DEF_RING 	"RING"			// It could be RING or +CRING (depends on AT+CRC)
 #define DEF_MSG 	"Msg:"			// Used by Java Client
-#define DEF_CLDEBUG 	"Msg:_DEBUG_("	        // Used by Java Client
+#define DEF_CLDEBUG "Msg:_DEBUG_("	// Used by Java Client
+#define DEF_CLPING  "Msg:Ping"	    // Used by Java Client
 
 #define CMER_ON  	1
 #define CMER_OFF  	2
@@ -132,6 +133,7 @@ enum CommandID {
 #define SET_FONT        "font"
 #define SET_FSCREEN     "fullscreen"
 #define SET_ICONS       "icons"
+#define SET_HINTS       "hints"
 #define SET_LIST        "list"
 #define SET_ILIST       "iconlist"
 #define SET_MENU        "menu"
@@ -158,6 +160,7 @@ enum CommandSetID {
     ID_SET_FONT,
     ID_SET_FSCREEN,
     ID_SET_ICONS,
+    ID_SET_HINTS,
     ID_SET_LIST,
     ID_SET_ILIST,
     ID_SET_MENU,
@@ -223,6 +226,13 @@ enum CommandGetID {
     ID_GET_MAX
 };
 
+enum CommandEventID {
+    ID_EVENT_FRONTEND,       
+    ID_EVENT_INIT,     
+    ID_EVENT_DISCONNECT,
+    ID_EVENT_EXIT,     
+};
+
 #define TIMER_CANCEL   "cancel"
 #define TIMER_PAUSE    "pause"
 #define TIMER_RESET    "reset"
@@ -245,14 +255,14 @@ enum CommandTimerID {
 #define UPLOAD_COVER_DATA "cover,noname"
 
 #define STR_MOTOROLA	"Motorola"
-#define STR_SE   	"Sony Ericsson"
-#define STR_SAGEM	"SAGEM"
+#define STR_SE   	    "Sony Ericsson"
+#define STR_SAGEM	    "SAGEM"
 #define STR_SIEMENS   	"SIEMENS"
 
 #define MODEL_DEFAULT	0
-#define MODEL_SE	1
+#define MODEL_SE	    1
 #define MODEL_MOTOROLA	2
-#define MODEL_SAGEM	3
+#define MODEL_SAGEM	    3
 #define MODEL_SIEMENS	4
 
 #define FLAG_EXACT	-1 // All non-negative values could be indexes in the list
@@ -280,7 +290,6 @@ typedef struct Cp {
 
 typedef struct {
     int   model;
-    char* cfgDir;
     int   frontEnd;
     uid_t   uid;
     gid_t   gid;
