@@ -2,7 +2,7 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2018 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -603,7 +603,7 @@ int openPeers()
 {
     DEBUG2("[DS]: openPeers %d", listSingleLength(_connections));
 
-    int ret = EXIT_NOK;
+    int ret = EXIT_OK;
     SingleList* list = _connections;
     while (list) {
         ConnectInfo* peer = (ConnectInfo*) list->data;
@@ -623,7 +623,15 @@ int openPeers()
                 ret = ret1;
             }
         } else {
-            DEBUG2("[DS]: openPeers peer %d have improper state %d", peer->id, peer->state);
+            DEBUG2("[DS]: openPeers peer %d have state %s", peer->id, 
+                    (peer->state == PEER_DISCONNECTED ? "DISCONNECTED" : 
+                     (peer->state == PEER_WAIT_LISTEN ? "WAIT_LISTEN" : 
+                      (peer->state == PEER_WAIT_ACCEPT ? "PEER_WAIT_ACCEPT" : 
+                       (peer->state == PEER_CONNECTED ? "CONNECTED" : "UNKNOWN")
+                      )
+                     )
+                    )
+                   );
         }
         list = listSingleNext(list);
     }
@@ -699,9 +707,10 @@ int disconnectPeersInternal(ConnectInfo* peer)
         }
        
     #endif
+    } else if (peer->mode == SERVER_WEB ||
+               peer->mode == SERVER_CMXML) {
+        canForceExit = 1;
     } else if (peer->mode == FRONT_END) {
-        canForceExit = 0;
-    } else {
         canForceExit = 1;
     }
 
@@ -1149,7 +1158,7 @@ static int doReadPeer(ConnectInfo* peer, int fd)
     char buf[MAXCMDLEN];
     memset(buf, 0, MAXCMDLEN);
     
-    DEBUG2("[DS]: doReadPeer() ready to read from fd %d (peer %d)", fd, peer->id);
+    //DEBUG2("[DS]: doReadPeer() ready to read from fd %d (peer %d)", fd, peer->id);
 
     int rc = 0;
     
@@ -1235,7 +1244,7 @@ int processPeers()
             //DEBUG2("[DS]: processPeers() error %d", errno);
             errnoDebug("[DS]: processPeers() select ",errno);  // testing debug
         } else {
-            DEBUG2("[DS]: --------------------------------------------");
+            //DEBUG2("[DS]: --------------------------------------------");
             //DEBUG2("[DS]: processPeers() got data from select()");
             
             list = _connections;
@@ -1247,11 +1256,11 @@ int processPeers()
 
                 if (fd >= 0) {
                 
-                    DEBUG2("[DS]: processPeers() %d descriptor on peer %d", fd, peer->id);
+                    //DEBUG2("[DS]: processPeers() %d descriptor on peer %d", fd, peer->id);
 
                     if (FD_ISSET(fd, &read_fds)) {
 		    
-		        //DEBUG2("[DS]: processPeers() FD_ISSET %d descriptor", fd);
+                        //DEBUG2("[DS]: processPeers() FD_ISSET %d descriptor", fd);
 
                         if (peer->state == PEER_CONNECTED) {
                             
