@@ -1756,51 +1756,54 @@ void webClose(ConnectInfo* conn, int final)
     //if (final) {  -- if app started then it will keep HTTP/XML connection opened
     
         _WebConnection* cn = (_WebConnection*) conn->connectionData;
-        INFO2("[WS]: webClose serverIP %s", cn->serverIP ? cn->serverIP->str : "NULL");
+        if (cn) {
+            INFO2("[WS]: webClose serverIP %s", 
+                  cn->serverIP && cn->serverIP->str ? cn->serverIP->str : "NULL");
 
-        // close all sockets
+            // close all sockets
 
-        mutexLock(M_WEB);
+            mutexLock(M_WEB);
 
-        INFO2("[WS]: clientSockets before cleanup #%d", listSingleLength(cn->clientSockets));
+            INFO2("[WS]: clientSockets before cleanup #%d", listSingleLength(cn->clientSockets));
 
-        SingleList* list = cn->clientSockets;
-        while (list) {
+            SingleList* list = cn->clientSockets;
+            while (list) {
 
-            int clientFD = CAST_POINTER_TO_INT(list->data);
-            if (clientFD > 0) {
-                close(clientFD);
+                int clientFD = CAST_POINTER_TO_INT(list->data);
+                if (clientFD > 0) {
+                    close(clientFD);
+                }
+                list = listSingleNext(list);
             }
-            list = listSingleNext(list);
-        }
 
-        listSingleFree(cn->clientSockets);
-        cn->clientSockets = NULL;
+            listSingleFree(cn->clientSockets);
+            cn->clientSockets = NULL;
 
-        mutexUnlock(M_WEB);
+            mutexUnlock(M_WEB);
 
-        if (cn->serverFileDescriptor >= 0) {
-            if (final) {
-                logger(L_INF, "closeSocket close web server socket");
+            if (cn->serverFileDescriptor >= 0) {
+                if (final) {
+                    logger(L_INF, "closeSocket close web server socket");
+                }
+                close(cn->serverFileDescriptor);
+                cn->serverFileDescriptor = -1;
             }
-            close(cn->serverFileDescriptor);
-            cn->serverFileDescriptor = -1;
-        }
 
-        if (cn->serverIP) {
-            INFO2("[WS]: serverIP %s", cn->serverIP->str);
-            stringFree(cn->serverIP, BOOL_YES);
-        }
+            if (cn->serverIP) {
+                INFO2("[WS]: serverIP %s", cn->serverIP->str);
+                stringFree(cn->serverIP, BOOL_YES);
+            }
 
-        if (cn->confDir) {
-            free(cn->confDir);
-            cn->confDir = NULL;
+            if (cn->confDir) {
+                free(cn->confDir);
+                cn->confDir = NULL;
+            }
+            mutexRemove(M_WEB);
+            queueRemove(Q_WEB, freeWMessage);
+
+            free(conn->connectionData);
+            conn->connectionData = NULL;
         }
-        mutexRemove(M_WEB);
-        queueRemove(Q_WEB, freeWMessage);
-        
-        free(conn->connectionData);
-        conn->connectionData = NULL;
     //}
     
     conn->state = PEER_DISCONNECTED;
