@@ -354,7 +354,7 @@ void printHelp()
     printf(" -name <SDP service name> if bluetooth or TCP/IP connection is used, allows one to specify SDP service name\n");
     printf(" -password ask password on connect\n");
     printf("           password should be stored in $HOME/.anyRemote/password file in a plain text\n");
-    printf(" -u|--user <username> if started from root, allows to set effective user ID to specified user\n\n");
+    printf(" -u|--user <username> if started from root, allows one to set effective user ID to specified user\n\n");
 
 }
 
